@@ -27,14 +27,15 @@ use autodie;
 
 use Date::Parse qw(str2time);
 use List::Util qw(first);
-use Moo;
 use POSIX qw(strftime);
 
 use Lintian::Data;
-use Lintian::Tags qw(tag);
 use Lintian::Util qw(internal_error);
 
-with('Lintian::Check');
+use Moo;
+use namespace::clean;
+
+with 'Lintian::Check';
 
 # Any Standards Version released before this day is "ancient"
 my $ANCIENT_DATE_DATA = Lintian::Data->new(
@@ -68,17 +69,18 @@ my @CURRENT      = split(m/\./, $CURRENT);
 sub source {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
     # udebs aren't required to conform to policy, so they don't need
     # Standards-Version. (If they have it, though, it should be valid.)
-    my $version = $info->field('standards-version');
+    my $version = $processable->field('standards-version');
     my $all_udeb = 1;
     $all_udeb = 0
-      if first { $info->binary_package_type($_) ne 'udeb' } $info->binaries;
+      if first { $processable->binary_package_type($_) ne 'udeb' }
+    $processable->binaries;
 
     if (not defined $version) {
-        tag 'no-standards-version-field' unless $all_udeb;
+        $self->tag('no-standards-version-field') unless $all_udeb;
         return;
     }
 
@@ -87,7 +89,7 @@ sub source {
     # change in Policy and is therefore meaningless in the Standards-Version
     # field.
     unless ($version =~ m/^\s*(\d+\.\d+\.\d+)(?:\.\d+)?\s*$/) {
-        tag 'invalid-standards-version', $version;
+        $self->tag('invalid-standards-version', $version);
         return;
     }
     my $stdver = $1;
@@ -98,8 +100,8 @@ sub source {
     # that the package was released today, since that activates the
     # most tags.
     my ($pkgdate, $dist);
-    if (defined $info->changelog) {
-        my ($entry) = @{$info->changelog->entries};
+    if (defined $processable->changelog) {
+        my ($entry) = @{$processable->changelog->entries};
         $pkgdate
           = ($entry && $entry->Timestamp) ? $entry->Timestamp : $CURRENT_DATE;
         $dist = ($entry && $entry->Distribution)? $entry->Distribution : '';
@@ -122,9 +124,11 @@ sub source {
             $package = strftime($fmt, gmtime $pkgdate);
             $release = strftime($fmt, gmtime $STANDARDS->value($stdver));
         }
-        tag 'timewarp-standards-version', "($package < $release)";
+        $self->tag('timewarp-standards-version', "($package < $release)");
     }
 
+    $self->tag('standards-version', $version);
+
     my $tag = "$version (current is $CURRENT)";
     if (not $STANDARDS->known($stdver)) {
         # Unknown standards version.  Perhaps newer?
@@ -135,9 +139,9 @@ sub source {
                 and $minor == $CURRENT[1]
                 and $patch > $CURRENT[2])
         ) {
-            tag 'newer-standards-version', $tag;
+            $self->tag('newer-standards-version', $tag);
         } else {
-            tag 'invalid-standards-version', $version;
+            $self->tag('invalid-standards-version', $version);
         }
     } elsif ($stdver eq $CURRENT) {
         # Current standard.  Nothing more to check.
@@ -154,21 +158,21 @@ sub source {
         my $released = strftime('%Y-%m-%d', gmtime $rdate);
         $tag = "$version (released $released) (current is $CURRENT)";
         if ($rdate < $ANCIENT_DATE) {
-            tag 'ancient-standards-version', $tag;
+            $self->tag('ancient-standards-version', $tag);
         } else {
             # We have to get the package date from the changelog file.  If we
             # can't find the changelog file, always issue the tag.
-            unless (defined $info->changelog) {
-                tag 'out-of-date-standards-version', $tag;
+            unless (defined $processable->changelog) {
+                $self->tag('out-of-date-standards-version', $tag);
                 return;
             }
-            my ($entry) = @{$info->changelog->entries};
+            my ($entry) = @{$processable->changelog->entries};
             my $timestamp
               = ($entry && $entry->Timestamp) ? $entry->Timestamp : 0;
             for my $standard (@STANDARDS) {
                 last if $standard->[0] eq $stdver;
                 if ($standard->[1] < $timestamp) {
-                    tag 'out-of-date-standards-version', $tag;
+                    $self->tag('out-of-date-standards-version', $tag);
                     last;
                 }
             }
